# Sparse Autoencoder (SAE) API

Sparse Autoencoders, training, concepts, and related modules for mechanistic interpretability.

## Core SAE Classes

::: amber.mechanistic.sae.sae.Sae

::: amber.mechanistic.sae.modules.topk_sae.TopKSae

::: amber.mechanistic.sae.autoencoder_context.AutoencoderContext

## Training

::: amber.mechanistic.sae.sae_trainer.SaeTrainer

::: amber.mechanistic.sae.sae_trainer.SaeTrainingConfig

::: amber.mechanistic.sae.modules.topk_sae.TopKSaeTrainingConfig

## Concepts

::: amber.mechanistic.sae.concepts.autoencoder_concepts.AutoencoderConcepts

::: amber.mechanistic.sae.concepts.concept_dictionary.ConceptDictionary

::: amber.mechanistic.sae.concepts.concept_models

::: amber.mechanistic.sae.concepts.input_tracker.InputTracker

## Training Utilities

::: amber.mechanistic.sae.training.wandb_logger.WandbLogger

